export interface PtUserAccountVO {
  /**
   * 账户Id,主键
   */
  userId: string | number;

  /**
   * 岗位Id
   */
  postId: string | number;

  /**
   * 部门Id
   */
  deptId: string | number;

  /**
   * 账户名/登录账号
   */
  userName: string;

  /**
   * 登录密码
   */
  password: string;

  /**
   * 账户编号/工号
   */
  userNumb: string;

  /**
   * 账户姓名
   */
  realName: string;

  /**
   * 账户性别,见sys_user_sex字典类型
   */
  sex: string;

  /**
   * 账户类型（0=内部账户 1=老师 2=学生 3=家长  4=其他人员）
   */
  category: string;

  /**
   * 账户邮箱
   */
  email: string;

  /**
   * 通信地址
   */
  address: string;

  /**
   * 手机号码
   */
  phone: string;

  /**
   * 头像地址
   */
  avatar: number;

  /**
   * 身份证号
   */
  idNumber: string | number;

  /**
   * 一卡通账户状态（0-未开户  1-已开户  -1已销户）
   */
  accountStatus: string;

  /**
   * 账户是否被冻结，见sys_yes_no字典类型
   */
  freezeStatus: string;

  /**
   * 消费密码
   */
  consumePwd: string;

  /**
   * 账户流水号
   */
  userNo: number;

  /**
   * 账户卡片类型
   */
  cardType: number;

  /**
   * 账户有效期
   */
  lifespan: string;

  /**
   * 64位2进制数据，某位的数据1代表具备某个属性
   */
  userAttr: number;

  /**
   * 人脸照片地址
   */
  photo: string;

  /**
   * 人员编制,对应 ZXXBZLB 字典类型
   */
  formation: string;

  /**
   * 是否隐藏,见sys_yes_no字典类型,内置的系统账号是需要隐藏的
   */
  hidden: string | number;

  /**
   * 唯一身份标识,第三方统一身份认证ID
   */
  otherId: string | number;

  /**
   * 第三方人员状态
   */
  userState: string;

  /**
   * 备注
   */
  remark: string;

  /**
   * 最后登录IP
   */
  loginIp: string;

  /**
   * 最后登录时间
   */
  loginDate: string;

  /**
   * 账户状态,见sys_normal_disable字典类型
   */
  status: string;

  /**
   * 账户卡片类型名称
   */
  cardTypeName?: string;

  /**
   * 账户余额
   */
  accountBalance?: string;

  /**
   * 账户发卡情况
   */
  accountCard?: string;
  /**
   * 部门名称
   */
  deptName?: string;
}

export interface PtUserAccountForm extends BaseEntity {
  /**
   * 账户Id,主键
   */
  userId?: string | number;

  /**
   * 岗位Id
   */
  postId?: string | number;

  /**
   * 部门Id
   */
  deptId?: string | number;
  /**
   * 部门名称
   */
  deptName?: string;
  /**
   * 账户名/登录账号
   */
  userName?: string;

  /**
   * 登录密码
   */
  password?: string;

  /**
   * 账户编号/工号
   */
  userNumb?: string;

  /**
   * 账户昵称
   */
  nickName?: string;

  /**
   * 账户姓名
   */
  realName?: string;

  /**
   * 账户性别,见sys_user_sex字典类型
   */
  sex?: string;

  /**
   * 账户类型（0=内部账户 1=老师 2=学生 3=家长  4=其他人员）
   */
  category?: string;

  /**
   * 账户邮箱
   */
  email?: string;

  /**
   * 通信地址
   */
  address?: string;

  /**
   * 手机号码
   */
  phone?: string;

  /**
   * 头像地址
   */
  avatar?: number;

  /**
   * 身份证号
   */
  idNumber?: string | number;

  /**
   * 一卡通账户状态（0-未开户  1-已开户  -1已销户）
   */
  accountStatus?: string;

  /**
   * 账户是否被冻结，见sys_yes_no字典类型
   */
  freezeStatus?: string;

  /**
   * 消费密码
   */
  consumePwd?: string;

  /**
   * 账户流水号
   */
  userNo?: number;

  /**
   * 账户卡片类型
   */
  cardType?: number;

  /**
   * 账户卡片类型名称
   */
  cardTypeName?: string;

  /**
   * 账户有效期
   */
  lifespan?: string;

  /**
   * 64位2进制数据，某位的数据1代表具备某个属性
   */
  userAttr?: number;

  /**
   * 人脸照片地址
   */
  photo?: string;

  /**
   * 人员编制,对应 ZXXBZLB 字典类型
   */
  formation?: string;

  /**
   * 是否隐藏,见sys_yes_no字典类型,内置的系统账号是需要隐藏的
   */
  hidden?: string | number;

  /**
   * 唯一身份标识,第三方统一身份认证ID
   */
  otherId?: string | number;

  /**
   * 第三方人员状态
   */
  userState?: string;

  /**
   * 备注
   */
  remark?: string;

  /**
   * 最后登录IP
   */
  loginIp?: string;

  /**
   * 最后登录时间
   */
  loginDate?: string;

  /**
   * 账户状态,见sys_normal_disable字典类型
   */
  status?: string;

  /**
   * 账户类型（sys_user一卡通账户）
   */
  userType?: string;

  /**
   * 账户余额
   */
  accountBalance?: string;
  /**
   * 账户发卡情况
   */
  accountCard?: string;
  /**
   * 账户卡片Id
   */
  cardId?: string | number;
}

export interface PtUserAccountQuery extends PageQuery {
  /**
   * 岗位Id
   */
  postId?: string | number;

  /**
   * 部门Id
   */
  deptId?: string | number;

  /**
   * 账户名/登录账号
   */
  userName?: string;

  /**
   * 登录密码
   */
  password?: string;

  /**
   * 账户编号/工号
   */
  userNumb?: string;

  /**
   * 账户昵称
   */
  nickName?: string;

  /**
   * 账户姓名
   */
  realName?: string;

  /**
   * 账户性别,见sys_user_sex字典类型
   */
  sex?: string;

  /**
   * 账户类型（0=内部账户 1=老师 2=学生 3=家长  4=其他人员）
   */
  category?: string;

  /**
   * 账户邮箱
   */
  email?: string;

  /**
   * 通信地址
   */
  address?: string;

  /**
   * 手机号码
   */
  phone?: string;

  /**
   * 头像地址
   */
  avatar?: number;

  /**
   * 身份证号
   */
  idNumber?: string | number;

  /**
   * 一卡通账户状态（0-未开户  1-已开户  -1已销户）
   */
  accountStatus?: string;

  /**
   * 账户是否被冻结，见sys_yes_no字典类型
   */
  freezeStatus?: string;

  /**
   * 消费密码
   */
  consumePwd?: string;

  /**
   * 账户流水号
   */
  userNo?: number;

  /**
   * 账户卡片类型
   */
  cardType?: number;

  /**
   * 账户有效期
   */
  lifespan?: string;

  /**
   * 64位2进制数据，某位的数据1代表具备某个属性
   */
  userAttr?: number;

  /**
   * 人脸照片地址
   */
  photo?: string;

  /**
   * 人员编制,对应 ZXXBZLB 字典类型
   */
  formation?: string;

  /**
   * 是否隐藏,见sys_yes_no字典类型,内置的系统账号是需要隐藏的
   */
  hidden?: string | number;

  /**
   * 唯一身份标识,第三方统一身份认证ID
   */
  otherId?: string | number;

  /**
   * 第三方人员状态
   */
  userState?: string;

  /**
   * 最后登录IP
   */
  loginIp?: string;

  /**
   * 最后登录时间
   */
  loginDate?: string;

  /**
   * 账户状态,见sys_normal_disable字典类型
   */
  status?: string;

  /**
   * 账户类型（sys_user一卡通账户）
   */
  userType?: string;

  /**
   * 日期范围参数
   */
  params?: any;
}
